@@ -14,7 +14,9 @@ class User(Model):
 class Permission(Model):
     label = fields.CharField(max_length=50)
     model = fields.CharField(max_length=50)
-    action: enums.PermissionAction = fields.IntEnumField(enums.PermissionAction, default=enums.PermissionAction.read)
+    action: enums.PermissionAction = fields.IntEnumField(
+        enums.PermissionAction, default=enums.PermissionAction.read, description="Permission Action"
+    )
 
     def __str__(self):
         return self.label
@@ -22,9 +24,9 @@ class Permission(Model):
 
 class Role(Model):
     label = fields.CharField(max_length=50)
-    users = fields.ManyToManyField('models.User')
+    users = fields.ManyToManyField("models.User")
 
-    permissions: fields.ManyToManyRelation[Permission] = fields.ManyToManyField('models.Permission')
+    permissions: fields.ManyToManyRelation[Permission] = fields.ManyToManyField("models.Permission")
 
     def __str__(self):
         return self.label
