@@ -2,29 +2,29 @@ from copy import deepcopy
 
 from fastapi import APIRouter, Depends
 
-from ..depends import get_current_user
+from ..depends import jwt_optional
 from ..factory import app
+from ..shortcuts import get_object_or_404
 
 router = APIRouter()
 
 
-@router.get(
-    '/site',
-)
-async def site(
-        user=Depends(get_current_user)
-):
+@router.get("/site",)
+async def site(user_id=Depends(jwt_optional)):
     site_ = app.site
-    if app.permission and not user.is_superuser:
+    user = None
+    if user_id:
+        user = await get_object_or_404(app.user_model, pk=user_id)
+    if user and app.permission and not user.is_superuser:
         site_ = deepcopy(site_)
-        await user.fetch_related('roles')
-        filter_menus = filter(lambda x: (x.url and 'rest' in x.url) or x.children, site_.menus)
+        await user.fetch_related("roles")
+        filter_menus = filter(lambda x: (x.url and "rest" in x.url) or x.children, site_.menus)
         hide_menus = []
         for menu in filter_menus:
             has_permission = False
             for role in user.roles:
                 if not has_permission:
-                    model = menu.url.split('/')[-1]
+                    model = menu.url.split("/")[-1]
                     permission = await role.permissions.filter(model=model)
                     if permission:
                         has_permission = True
